<?php
/*
Copyright: © 2009 WebSharks, Inc. ( coded in the USA )
<mailto:support@websharks-inc.com> <http://www.websharks-inc.com/>

Released under the terms of the GNU General Public License.
You should have received a copy of the GNU General Public License,
along with this software. In the main directory, see: /licensing/
If not, see: <http://www.gnu.org/licenses/>.
*/
/*
WARNING: This is a system configuration file, please DO NOT EDIT this file directly!
... Instead, use the plugin options panel in WordPress® to override these settings.
*/
if (realpath (__FILE__) === realpath ($_SERVER["SCRIPT_FILENAME"]))
	exit ("Do not access this file directly.");
/*
Determine the full url to the directory this plugin resides in.
*/
$GLOBALS["WS_PLUGIN__"]["qcache"]["c"]["dir_url"] = (stripos (__FILE__, WP_CONTENT_DIR) !== 0) ? /* Have to assume plugins dir? */
plugins_url ("/" . basename (dirname (dirname (__FILE__)))) : /* Otherwise, this gives it a chance to live anywhere in the content dir. */
content_url (preg_replace ("/^(.*?)\/" . preg_quote (basename (WP_CONTENT_DIR), "/") . "/", "", str_replace (DIRECTORY_SEPARATOR, "/", dirname (dirname (__FILE__)))));
/*
Check if the plugin has been configured *should be set after the first config via options panel*.
*/
$GLOBALS["WS_PLUGIN__"]["qcache"]["c"]["configured"] = get_option ("ws_plugin__qcache_configured");
/*
Configure the right menu options panel for this software.
*/
$GLOBALS["WS_PLUGIN__"]["qcache"]["c"]["menu_pages"] = array ("installation" => false, "tools" => true, "videos" => false, "support" => true, "donations" => true);
/*
Configure checksum time for the syscon.inc.php file.
*/
$GLOBALS["WS_PLUGIN__"]["qcache"]["c"]["checksum"] = filemtime (__FILE__);
/*
Configure & validate all of the plugin options; and set their defaults.
*/
if (!function_exists ("ws_plugin__qcache_configure_options_and_their_defaults"))
	{
		function ws_plugin__qcache_configure_options_and_their_defaults ($options = FALSE) /* Can also be used to merge options with defaults. */
			{
				/* Here we build the default options array, which will be merged with the user options.
				It is important to note that sometimes default options may not or should not be pre-filled on an options form.
				These defaults are for the system to use in various ways, we may choose not to pre-fill certain fields.
				In other words, some defaults may be used internally, but to the user, the option will be empty. */
				$default_options = apply_filters ("ws_plugin__qcache_default_options", array ( /* For filters. */
				/**/
				"options_checksum" => "", /* Used internally to maintain the integrity of all options in the array. */
				/**/
				"options_version" => "1.0", /* Used internally to maintain the integrity of all options in the array. */
				/**/
				"run_deactivation_routines" => "1", /* Should deactivation routines be processed? */
				/**/
				"enabled" => "0", /* Whether or not Quick Cache has been enabled. Initially disabled. */
				/**/
				"enable_debugging" => "0", /* Enable the built-in debugging routines for Quick Cache?. */
				/**/
				"dont_cache_when_logged_in" => "1", /* Logged in users should NOT receive cached versions. */
				/**/
				"dont_cache_query_string_requests" => "1", /* Normally, GET requests should NOT be cached. */
				/**/
				"allow_browser_cache" => "0", /* Allow the browser to cache a cached file? Recommended false. */
				/**/
				"expiration" => "3600", /* How long are cache files good for? This number is in seconds please. */
				/**/
				"clear_on_update" => "single", /* Clear the cache on update? This can be none, single, or all. */
				/**/
				"dont_cache_these_uris" => "wp-app\nwp-signup\nwp-register\nwp-activate\nwp-login\nwp-admin\nxmlrpc",/**/
				"dont_cache_these_refs" => "", /* HTTP referrers, and/or referrer patterns that should NOT be cached. */
				"dont_cache_these_agents" => "w3c_validator", /* User-Agents and/or User-Agent patterns NOT to cache. */
				/**/
				"use_flock_or_sem" => "sem", /* Use flock() or should we use semiaphores? Please type flock or sem. */
				/**/
				"version_salt" => "", /* Multiple versions of each page can be cached using a Salt in the mix. */
				/**/
				"auto_cache_enabled" => "0", /* Enable the built-in auto-caching routines? */
				"auto_cache_agent" => "Mozilla/5.0 (Windows; U; Windows NT 6.0; en-US; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3",/**/
				"auto_cache_sitemap_url" => "", /* If auto caching is enabled, where is the XML sitemap? */
				"auto_cache_additional_urls" => "", /* If auto caching is enabled, use these additional urls. */
				"auto_cache_max_processes" => "5")); /* How many auto-cache processes can be spawned at one time? */
				/*
				Here they are merged. User options will overwrite some or all default values. 
				*/
				$GLOBALS["WS_PLUGIN__"]["qcache"]["o"] = array_merge ($default_options, ( ($options !== false) ? (array)$options : (array)get_option ("ws_plugin__qcache_options")));
				/*
				This builds an MD5 checksum for the full array of options. This also includes the config checksum and the current set of default options. 
				*/
				$checksum = md5 (($checksum_prefix = $GLOBALS["WS_PLUGIN__"]["qcache"]["c"]["checksum"] . serialize ($default_options)) . serialize (array_merge ($GLOBALS["WS_PLUGIN__"]["qcache"]["o"], array ("options_checksum" => 0))));
				/*
				Validate each option, possibly reverting back to the default value if invalid.
				Also check if options were passed in on some of these, in case empty values are to be allowed. 
				*/
				if ($options !== false || ($GLOBALS["WS_PLUGIN__"]["qcache"]["o"]["options_checksum"] !== $checksum && $GLOBALS["WS_PLUGIN__"]["qcache"]["o"] !== $default_options))
					{
						foreach ($GLOBALS["WS_PLUGIN__"]["qcache"]["o"] as $key => &$value)
							{
								if (!isset ($default_options[$key]) && !preg_match ("/^pro_/", $key))
									unset ($GLOBALS["WS_PLUGIN__"]["qcache"]["o"][$key]);
								/**/
								else if ($key === "options_checksum" && (!is_string ($value) || !strlen ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "options_version" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "run_deactivation_routines" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "enabled" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "enable_debugging" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "dont_cache_when_logged_in" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "dont_cache_query_string_requests" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "allow_browser_cache" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "expiration" && (!is_string ($value) || !is_numeric ($value) || $value < 1))
									$value = $default_options[$key];
								/**/
								else if ($key === "clear_on_update" && (!is_string ($value) || !preg_match ("/^(none|single|single-fp|all)$/", $value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "dont_cache_these_uris" && (!is_string ($value) || !strlen ($value))) /* Should always have defaults. */
									$value = $default_options[$key];
								/**/
								else if ($key === "dont_cache_these_refs" && !is_string ($value)) /* Allowed to be non-default empty. */
									$value = $default_options[$key];
								/**/
								else if ($key === "dont_cache_these_agents" && !is_string ($value)) /* Allowed to be non-default empty. */
									$value = $default_options[$key];
								/**/
								else if ($key === "use_flock_or_sem" && (!is_string ($value) || !preg_match ("/^(flock|sem)$/", $value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "version_salt" && (!is_string ($value) || !is_string ($value = trim ($value, " ."))))
									$value = $default_options[$key];
								/**/
								else if ($key === "auto_cache_enabled" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "auto_cache_agent" && (!is_string ($value) || !strlen ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "auto_cache_sitemap_url" && (!is_string ($value) || !strlen ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "auto_cache_additional_urls" && (!is_string ($value) || !strlen ($value)))
									$value = $default_options[$key];
								/**/
								else if ($key === "auto_cache_max_processes" && (!is_string ($value) || !is_numeric ($value)))
									$value = $default_options[$key];
							}
						/**/
						$GLOBALS["WS_PLUGIN__"]["qcache"]["o"] = apply_filters_ref_array ("ws_plugin__qcache_options_before_checksum", array (&$GLOBALS["WS_PLUGIN__"]["qcache"]["o"]));
						/**/
						$GLOBALS["WS_PLUGIN__"]["qcache"]["o"]["options_checksum"] = md5 ($checksum_prefix . serialize (array_merge ($GLOBALS["WS_PLUGIN__"]["qcache"]["o"], array ("options_checksum" => 0))));
					}
				/**/
				return apply_filters_ref_array ("ws_plugin__qcache_options", array (&$GLOBALS["WS_PLUGIN__"]["qcache"]["o"]));
			}
	}
?>